==> babel-esnext-0.2.0.tgz: package/dist.js <==
#!/usr/bin/env node
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _babelCore = require('babel-core');

var _child_process = require('child_process');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toArray(arr) { return Array.isArray(arr) ? arr : Array.from(arr); }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function startShell() {
  var restArgs = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];

  // Spawn a babel-node shell in the correct location:
  var fullArgs = ['--presets', 'es2015,stage-0'].concat(_toConsumableArray(restArgs));
  var binPath = _path2.default.resolve(__dirname, 'node_modules', '.bin', 'babel-node');
  var proc = (0, _child_process.spawn)(binPath, fullArgs, {
    stdio: 'inherit',
    cwd: __dirname
  });

  proc.on('exit', process.exit);
}

function runFile(filename) {
  // As babel-node won't let us run files with a different working directory,
  // we'll need to compile it manually with Babel, and then pipe it
  // into a regular Node process (kind of hacky):
  var originalPath = process.cwd();
  var file = _fs2.default.readFileSync(separator).toString();

  // Babel needs to be in the same folder as node_modules to access the
  // presets/plugins:
  process.chdir(__dirname);

  var _transform = (0, _babelCore.transform)(file, {
    presets: ['es2015', 'stage-0']
  });

  var code = _transform.code;

  // We still want to run Node from our original directory though:
  process.chdir(originalPath);
  var proc = (0, _child_process.spawn)('node');
  proc.stdout.pipe(process.stdout);
  proc.stderr.pipe(process.stderr);
  proc.stdin.write(code);
  proc.stdin.end();
}

var args = process.argv.slice(2);

var _args = _toArray(args);

var separator = _args[0];

var rest = _args.slice(1);

if (separator === '--' || !args.length) {
  console.log(rest);
  startShell(rest);
} else if (separator) {
  runFile(separator);
}

==> babel-esnext-0.2.1.tgz: package/dist.js <==
#!/usr/bin/env node
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _babelCore = require('babel-core');

var _child_process = require('child_process');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toArray(arr) { return Array.isArray(arr) ? arr : Array.from(arr); }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function startShell(restArgs) {
  // Spawn a babel-node shell in the correct location:
  var fullArgs = ['--presets', 'es2015,stage-0'].concat(_toConsumableArray(restArgs));
  var binPath = _path2.default.resolve(__dirname, 'node_modules', '.bin', 'babel-node');
  var proc = (0, _child_process.spawn)(binPath, fullArgs, {
    stdio: 'inherit',
    cwd: __dirname
  });

  proc.on('exit', process.exit);
}

function runFile(filename) {
  // As babel-node won't let us run files with a different working directory,
  // we'll need to compile it manually with Babel, and then pipe it
  // into a regular Node process (kind of hacky):
  var originalPath = process.cwd();
  var file = _fs2.default.readFileSync(separator).toString();

  // Babel needs to be in the same folder as node_modules to access the
  // presets/plugins:
  process.chdir(__dirname);

  var _transform = (0, _babelCore.transform)(file, {
    presets: ['es2015', 'stage-0']
  });

  var code = _transform.code;

  // We still want to run Node from our original directory though:
  process.chdir(originalPath);
  var proc = (0, _child_process.spawn)('node');
  proc.stdout.pipe(process.stdout);
  proc.stderr.pipe(process.stderr);
  proc.stdin.write(code);
  proc.stdin.end();
}

var args = process.argv.slice(2);

var _args = _toArray(args);

var separator = _args[0];

var rest = _args.slice(1);

if (separator === '--' || !args.length) {
  startShell(rest);
} else if (separator) {
  runFile(separator);
}
